//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Base/Axis/FixedBinAxis.h
//! @brief     Defines class FixedBinAxis.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_BASE_AXIS_FIXEDBINAXIS_H
#define BORNAGAIN_BASE_AXIS_FIXEDBINAXIS_H

#include "Base/Axis/IAxis.h"

//! Axis with fixed bin size.

class FixedBinAxis : public IAxis {
public:
    //! FixedBinAxis constructor.
    //! @param name Axis name
    //! @param nbins number of bins
    //! @param start low edge of first bin
    //! @param end upper edge of last bin
    FixedBinAxis(const std::string& name, size_t nbins, double start, double end);
    ~FixedBinAxis() override = default;
    FixedBinAxis(FixedBinAxis&&) = default;

    FixedBinAxis* clone() const override;

    void clip(double lower, double upper) override;

protected:
    void print(std::ostream& ostr) const override;
    bool equals(const IAxis& other) const override;

private:
    size_t m_nbins;
    double m_start;
    double m_end;
};

#ifndef SWIG
//! Returns a FixedBinAxis determined by first and last point in scan.
FixedBinAxis FixedScanAxis(const std::string& name, size_t nbins, double scan_start,
                           double scan_end);
#endif

#endif // BORNAGAIN_BASE_AXIS_FIXEDBINAXIS_H
